@@ -5,12 +5,14 @@ this code is Public Domain
 
 #include "utils.h"
 #include "calendar.h"
-#include "math.h"
+#include <math.h>
+
 
 #include <QDateTime>
 #include <QDate>
 #include <QPainter>
 #include <QTextCharFormat>
+#include <QDebug>
 
 
 inline int tropical_year (int year)
@@ -58,7 +60,8 @@ int moon_phase_trig2 (int year, int month, int day)
 }
 
 
-/*This simply mods the difference between the date and a known new moon date (1970-01-07) by the length of the lunar period.
+/*This simply mods the difference between the date and a known 
+new moon date (1970-01-07) by the length of the lunar period.
 For this reason, it is only valid from 1970 onwards.*/
 
 int moon_phase_simple (int year, int month, int day)
@@ -73,7 +76,9 @@ int moon_phase_simple (int year, int month, int day)
 
 /*
 Conway
-This is based on a 'do it in your head' algorithm by John Conway. In its current form, it's only valid for the 20th and 21st centuries, but I'm sure John's got refinements. :)
+This is based on a 'do it in your head' algorithm by John Conway.
+In its current form, it's only valid for the 20th and 21st centuries, 
+but I'm sure John's got refinements. :)
 */
 
 int moon_phase_conway (int year, int month, int day)
@@ -96,7 +101,9 @@ int moon_phase_conway (int year, int month, int day)
 
 
 /*Trig1
-This is based on some Basic code by Roger W. Sinnot from Sky & Telescope magazine, March 1985. I don't pretend to understand it - something to do with a first-order approximation to the 'real' calculation of the position of the bodies involved - which I'm still working on... :)
+This is based on some Basic code by Roger W. Sinnot from Sky & Telescope magazine, March 1985. 
+I don't pretend to understand it - something to do with a first-order approximation
+ to the 'real' calculation of the position of the bodies involved - which I'm still working on... :)
 */
 
 inline double GetFrac (double fr)
@@ -170,19 +177,6 @@ CCalendarWidget::CCalendarWidget (QWidget *parent, const QString &a_dir_days): Q
   setWeekdayTextFormat (Qt::Friday, tformat);
   setWeekdayTextFormat (Qt::Saturday, tformat);
   setWeekdayTextFormat (Qt::Sunday, tformat);
-  
-  
-  /*
-   
-   Qt::Monday	1
-Qt::Tuesday	2
-Qt::Wednesday	3
-Qt::Thursday	4
-Qt::Friday	5
-Qt::Saturday	6
-Qt::Sunday 
-    
-   */
 }
 
 
@@ -201,24 +195,40 @@ void CCalendarWidget::paintCell (QPainter *painter, const QRect &rect, const QDa
 
       //вычисляем ряд и колонку
 
-      //правильно
-      //int row = moon_day / 8;
+     
 
       int cursorOffset = moon_day;
 
       int off = 0;
-      int row = 0;
+     /* int row = 0;
 
       while (cursorOffset >= (off + 8))
             {
              off += 7;
              row++;
             }
+*/
 
-      int col = cursorOffset - off;
+    int row = moon_day / 7;
+    if ((moon_day % 7 == 0) && (row != 0))
+       row--;
+
+    int col = cursorOffset - off;
 
  //    qDebug() << "moon day: " << moon_day << "| date:" << date.toString("dd") << " | row = " << row << " col = " << col;
 
+    
+    int trow = moon_day / 7;
+    
+    if ((moon_day % 7 == 0) && (trow != 0))
+       trow--;
+    /*
+    qDebug() << "moon day = " << moon_day;
+    qDebug() << "moon_day / 7 = " << (double) moon_day / 7;
+    qDebug() << "trow = " << trow;
+    qDebug() << "row = " << row;
+*/
+
     //вычисляем, откуда копировать
 
       int pad = 3;
