@@ -1,5 +1,5 @@
 /***************************************************************************
- *   2007-2016 by Peter Semiletov <tea@list.ru>                            *
+ *   2007-2017 by Peter Semiletov <peter.semiletov@gmail.com>                            *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -66,14 +66,13 @@ class CDocument;
 class CTEAEdit: public QPlainTextEdit
 {
   Q_OBJECT
-
-   
+  
 
 public:
 
   QString indent_val;  
   QList <QTextEdit::ExtraSelection> extraSelections;
-  QTextEdit::ExtraSelection selection;
+  QTextEdit::ExtraSelection brace_selection;
 
   
   //rect selection
@@ -81,8 +80,6 @@ public:
   QPoint rect_sel_start;
   QPoint rect_sel_end;
  
- 
-
   CDocument *doc;
 
   QColor currentLineColor;
@@ -91,6 +88,10 @@ public:
   QColor linenums_bg;
   QColor text_color;
 
+  QColor sel_text_color;
+  QColor sel_back_color;
+
+
   QWidget *lineNumberArea;
 
   bool highlightCurrentLine;
@@ -124,22 +125,38 @@ public:
   void calc_auto_indent();
   void setup_brace_width();
 
+  void text_replace (const QString &s);
+
   void rect_sel_reset();
-  void rect_sel_replace (const QString &s);
+  void rect_sel_replace (const QString &s, bool insert = false);
+  //void rect_sel_insert (const QString &s);
+  
+  
+  void update_ext_selections();
+  
   
   void update_rect_sel();
   
   QString get_rect_sel();
 
+  void rect_sel_cut (bool just_del = false);
+
+
   void braceHighlight();
   
   void lineNumberAreaPaintEvent(QPaintEvent *event);
   int lineNumberAreaWidth();
 
+
+  Q_INVOKABLE bool has_rect_selection();
+  
+
 protected:
 
   bool canInsertFromMimeData (const QMimeData *source);
   void insertFromMimeData (const QMimeData *source);
+  
+  QMimeData* createMimeDataFromSelection(); 
 
   void paintEvent(QPaintEvent *event);
   void keyPressEvent (QKeyEvent *event);    
@@ -155,11 +172,16 @@ protected:
 
     }
 */
-private slots:
+public slots:
 
   void updateLineNumberAreaWidth (int newBlockCount);
   void cb_cursorPositionChanged();
   void updateLineNumberArea (const QRect &, int);
+  
+  void slot_selectionChanged();
+  
+ // void copy();
+  
 };
 
 
@@ -299,6 +321,7 @@ public:
   Q_INVOKABLE void update_status();
   Q_INVOKABLE void update_title (bool fullname = true);
 
+
   Q_INVOKABLE void update_labels();
 };
 
