@@ -3,8 +3,6 @@ this code is Public Domain
 */
 
 
-#include "img_viewer.h"
-#include "utils.h"
 
 #include <QDebug>
 
@@ -19,6 +17,16 @@ this code is Public Domain
 #include <QImageReader>
 #include <QKeyEvent>
 
+#include <QSettings>
+
+#include "img_viewer.h"
+
+#include "exif.h"
+#include "utils.h"
+
+
+extern QSettings *settings;
+
 
 CImgViewer::CImgViewer (QObject *parent): QObject (parent)
 {
@@ -59,7 +67,7 @@ void CImgViewer::set_image_full (const QString &fname)
 {
  // window_full.show_image (fname);
   window_full.load_image (fname);
- 
+  //qDebug() << "get_exif_orintation " << get_exif_orintation (fname);
 }
 
 
@@ -378,7 +386,7 @@ void CZORWindow::load_image (const QString &fname)
   if (! file_exists (fname))
      return;
 
-  qDebug() << "CZORWindow::load_image " << fname;
+ // qDebug() << "CZORWindow::load_image " << fname;
   
   fname_image = fname;
  
@@ -387,6 +395,14 @@ void CZORWindow::load_image (const QString &fname)
      
   
   bool orientation_portrait = false; 
+  
+  int exif_orientation = get_exif_orientation (fname);
+ // qDebug() << "exif_orientation: " << exif_orientation;
+  
+  if (settings->value ("zor_use_exif_orientation", 0).toInt())
+  if (exif_orientation == 6 || exif_orientation == 8)
+     orientation_portrait = true;
+  
   bool need_to_scale = false;
   
   if (source_image.size().height() > source_image.size().height())
@@ -395,6 +411,37 @@ void CZORWindow::load_image (const QString &fname)
   if (source_image.size().height() > 600 || source_image.size().width() > 800)
      need_to_scale = true;
   
+  if (exif_orientation == 3)
+     {
+      QTransform transform;
+      
+      transform.rotate (180);
+      
+      QImage transformed_image = source_image.transformed (transform);
+      transformed_image = transformed_image.scaled (size(), Qt::KeepAspectRatio, Qt::SmoothTransformation);
+      source_image = transformed_image;
+     }
+     
+  
+  if (orientation_portrait)
+     {
+      QTransform transform;
+      
+      qreal angle;
+      
+      if (exif_orientation == 6)
+         angle = 90;
+      else   
+      if (exif_orientation == 8) //make clockwise
+         angle = 270;
+      
+      transform.rotate (angle);
+      
+      QImage transformed_image = source_image.transformed (transform);
+      transformed_image = transformed_image.scaled (size(), Qt::KeepAspectRatio, Qt::SmoothTransformation);
+      source_image = transformed_image;
+     }
+  
   if (need_to_scale)
     {  
      if (orientation_portrait)
@@ -427,3 +474,56 @@ void CZORWindow::keyPressEvent (QKeyEvent * event)
 
   event->accept();
 }
+
+
+
+void CGIFWindow::keyPressEvent (QKeyEvent * event)
+{
+  if (event->key() == Qt::Key_Escape)
+     {
+      event->accept();
+      close();
+     }
+
+  event->accept();
+}
+
+
+void CGIFWindow::load_image (const QString &fname)
+{
+  if (! file_exists (fname))
+     return;
+     
+  if (movie)
+     delete movie;   
+     
+  movie = new QMovie (fname);
+  setMovie (movie);
+  
+  movie->jumpToFrame (0);  
+  resize (movie->currentImage().size()); 
+  
+  show();
+  
+  movie->start(); 
+}
+
+
+CGIFWindow::CGIFWindow (QWidget *parent): QLabel (parent)
+{
+  movie = 0;
+}
+
+
+CGIFWindow::~CGIFWindow()
+{
+  if (movie)
+    delete movie;
+}
+
+
+
+void CGIFWindow::closeEvent (QCloseEvent *event)
+{
+  event->accept();
+}
