@@ -28,11 +28,18 @@ you are using Open Source edition of Qt, you therefore MUST use GPL for
 your code based on QuaZIP, since it would be also based on Qt in this
 case. If you are Qt commercial license owner, then you are free to use
 QuaZIP as long as you respect either GPL or LGPL for QuaZIP code.
+
+
+----
+modified by Peter Semiletov
  */
 
-#include <QFile>
-
 #include "quazip.h"
+ 
+
+#include <QFile>
+#include <QDebug>
+
 
 QuaZip::QuaZip():
                  fileNameCodec (QTextCodec::codecForLocale()),
@@ -50,7 +57,10 @@ QuaZip::QuaZip (const QString& zipName, const QString &fnamecodec):
                hasCurrentFile_f (false),
                zipError(UNZ_OK)
 {
-  fileNameCodec = QTextCodec::codecForName (fnamecodec.toAscii());
+ if (fnamecodec.isEmpty())
+    fileNameCodec = QTextCodec::codecForName ("UTF-8");
+ else
+    fileNameCodec = QTextCodec::codecForName (fnamecodec.toLatin1());
 }
 
 
@@ -64,6 +74,7 @@ QuaZip::~QuaZip()
 bool QuaZip::open (Mode mode, zlib_filefunc_def *ioApi)
 {
   zipError = UNZ_OK;
+  
   if (isOpen())
      {
       qWarning ("QuaZip::open(): ZIP already opened");
@@ -205,19 +216,19 @@ QString QuaZip::getComment() const
 bool QuaZip::setCurrentFile (const QString &fileName, CaseSensitivity cs)
 {
   zipError = UNZ_OK;
-
+  
   if (mode != mdUnzip)
      {
       qWarning ("QuaZip::setCurrentFile(): ZIP is not open in mdUnzip mode");
       return false;
      }
-
+     
   if (fileName.isNull())
      {
       hasCurrentFile_f = false;
       return true;
      }
-
+       
   // Unicode-aware reimplementation of the unzLocateFile function
   if (! unzFile_f)
      {
@@ -225,34 +236,40 @@ bool QuaZip::setCurrentFile (const QString &fileName, CaseSensitivity cs)
       return false;
      }
 
+     
   if (fileName.length() > MAX_FILE_NAME_LENGTH)
      {
       zipError = UNZ_PARAMERROR;
       return false;
      }
-
+     
   bool sens;
 
   if (cs == csDefault)
     {
-#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
-     sens=false;
+     
+#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+     sens = false;
 #else
-     sens=true;
+     sens = true;
 #endif
     }
   else
       sens = cs == csSensitive;
 
+  
   QString lower, current;
+
   if (! sens)
      lower = fileName.toLower();
 
   hasCurrentFile_f = false;
-
+   
+     
   for (bool more = goToFirstFile(); more; more = goToNextFile())
       {
        current = getCurrentFileName();
+       
        if (current.isNull())
           return false;
 
@@ -264,14 +281,17 @@ bool QuaZip::setCurrentFile (const QString &fileName, CaseSensitivity cs)
       else
            if (current.toLower() == lower)
                break;
-  }
+      }
 
+ 
   return hasCurrentFile_f;
 }
 
+
 bool QuaZip::goToFirstFile()
 {
   zipError = UNZ_OK;
+  
   if (mode != mdUnzip)
      {
       qWarning ("QuaZip::goToFirstFile(): ZIP is not open in mdUnzip mode");
@@ -287,6 +307,7 @@ bool QuaZip::goToFirstFile()
 bool QuaZip::goToNextFile()
 {
   zipError = UNZ_OK;
+  
   if (mode != mdUnzip)
      {
       qWarning ("QuaZip::goToFirstFile(): ZIP is not open in mdUnzip mode");
@@ -377,6 +398,8 @@ QString QuaZip::getCurrentFileName() const
   if ((fakeThis->zipError = unzGetCurrentFileInfo (unzFile_f, NULL, fileName.data(), fileName.size(),
                                                    NULL, 0, NULL, 0)) != UNZ_OK)
      return QString();
-
-  return fileNameCodec->toUnicode(fileName.constData());
+  
+  QString result = fileNameCodec->toUnicode(fileName.constData());
+  
+  return result;
 }
