@@ -8,28 +8,38 @@
 #ifndef SINGLE_APP_SHARED_H
 #define SINGLE_APP_SHARED_H
 
-#ifndef Q_OS_OS2
 
 #include <QApplication>
-#include <QSharedMemory>
 #include <QStringList>
-#include <QSharedMemory>
 #include <QLocalServer>
 
-class CSingleApplicationShared : public QApplication
+#ifndef Q_OS_OS2
+#include <QSharedMemory>
+#endif
+
+
+class CSingleApplicationShared: public QApplication
 {
         Q_OBJECT
 public:
         CSingleApplicationShared (int &argc, char *argv[], const QString uniqueKey);
+           
+        ~CSingleApplicationShared() {qDebug() << "~CSingleApplicationShared";};  
 
-        static int cursorFlashTime() {return 0;}; 
+        static int cursorFlashTime() 
+               {
+                return 0;
+               } 
         
-         bool alreadyExists() const{
-            return bAlreadyExists;
-        }
-        bool isMasterApp() const{
-            return !alreadyExists();
-        }
+        bool alreadyExists() const
+             {
+              return bAlreadyExists;
+              }
+        
+        bool isMasterApp() const
+             {
+              return !alreadyExists();
+              }
 
         bool sendMessage(const QString &message);
         
@@ -43,10 +53,13 @@ signals:
  
 private:
         bool bAlreadyExists;
+        
+#ifndef Q_OS_OS2
+        
         QSharedMemory sharedMemory;
+#endif        
 };
 
-#endif //if not def OS/2
 
 #endif // SINGLE_APP_SHARED_H
 
